---
search:
  exclude: true
---
# コード例

[repo](https://github.com/openai/openai-agents-python/tree/main/examples) の コード例 セクションで、SDK のさまざまなサンプル実装をご覧ください。これらのコード例は、異なるパターンや機能を示す複数の カテゴリー に整理されています。


## カテゴリー

- **[agent_patterns](https://github.com/openai/openai-agents-python/tree/main/examples/agent_patterns):**
  このカテゴリーの例では、次のような一般的な エージェント の設計パターンを示します。

    - 決定的なワークフロー
    - ツールとしての エージェント
    - エージェント の並列実行

- **[basic](https://github.com/openai/openai-agents-python/tree/main/examples/basic):**
  このカテゴリーの例では、SDK の基礎的な機能を紹介します。

    - 動的な システムプロンプト
    - ストリーミング 出力
    - ライフサイクルイベント

- **[ツールのコード例](https://github.com/openai/openai-agents-python/tree/main/examples/tools):**
  Web 検索 や ファイル検索 といった OpenAI がホストするツール の実装方法と、それらを エージェント に統合する方法を学べます。

- **[モデルプロバイダー](https://github.com/openai/openai-agents-python/tree/main/examples/model_providers):**
  SDK で OpenAI 以外のモデルを使う方法を紹介します。

- **[ハンドオフ](https://github.com/openai/openai-agents-python/tree/main/examples/handoffs):**
  エージェント の ハンドオフ の実践的な例をご覧ください。

- **[mcp](https://github.com/openai/openai-agents-python/tree/main/examples/mcp):**
  MCP で エージェント を構築する方法を学べます。

- **[customer_service](https://github.com/openai/openai-agents-python/tree/main/examples/customer_service)** と **[research_bot](https://github.com/openai/openai-agents-python/tree/main/examples/research_bot):**
  より作り込まれた、実運用に近い例を 2 つ紹介します。

    - **customer_service**: 航空会社向けのカスタマーサービス システムの例。
    - **research_bot**: シンプルな ディープリサーチ のクローン。

- **[voice](https://github.com/openai/openai-agents-python/tree/main/examples/voice):**
  TTS と STT モデルを用いた音声 エージェント の例。

- **[realtime](https://github.com/openai/openai-agents-python/tree/main/examples/realtime):**
  SDK を使って リアルタイム 体験を構築する方法の例。